# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# OFFICE
class OfficeSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office'
        model = models.Office
        fields = '__all__'


class OfficeListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_list'
        model = models.Office
        fields = '__all__'


class OfficeRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_retrieve'
        model = models.Office
        fields = '__all__'


class OfficeCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_create'
        model = models.Office
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OfficeRetrieveSerializer


class OfficeUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_update'
        model = models.Office
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OfficeRetrieveSerializer


class OfficePartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_office_office_partial_update'
        model = models.Office
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OfficeRetrieveSerializer


class OfficeEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_enable'
        model = models.Office
        fields = ()
        response_serializer = OfficeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OfficeDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_disable'
        model = models.Office
        fields = ()
        response_serializer = OfficeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OfficeLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_light'
        model = models.Office
        fields = ('id', 'status', 'status_display',)


# AREA
class AreaSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area'
        model = models.Area
        fields = '__all__'


class AreaListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_list'
        model = models.Area
        fields = '__all__'


class AreaRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_retrieve'
        model = models.Area
        fields = '__all__'


class AreaCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_create'
        model = models.Area
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AreaRetrieveSerializer


class AreaUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_update'
        model = models.Area
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AreaRetrieveSerializer


class AreaPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_office_area_partial_update'
        model = models.Area
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AreaRetrieveSerializer


class AreaEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_enable'
        model = models.Area
        fields = ()
        response_serializer = AreaRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class AreaDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_disable'
        model = models.Area
        fields = ()
        response_serializer = AreaRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class AreaLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_light'
        model = models.Area
        fields = ('code', 'status', 'status_display',)
